==> kfzcheck_2.0-0.tar.gz: kfzcheck-2.0/src/opt/kfzcheck/locale/de_DE.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="de_DE">
<context>
    <name>KFZcheck</name>
    <message>
        <location filename="gui.ui" line="117"/>
        <source>Middle</source>
        <translation>Mitte</translation>
    </message>
    <message>
        <location filename="gui.ui" line="128"/>
        <source>Top</source>
        <translation>Oben</translation>
    </message>
    <message>
        <location filename="gui.ui" line="139"/>
        <source>Bottom</source>
        <translation>Unten</translation>
    </message>
    <message>
        <location filename="gui.ui" line="144"/>
        <source>Country</source>
        <translation>Land</translation>
    </message>
    <message>
        <location filename="kfzcheck.py" line="208"/>
        <source>About</source>
        <translation>Über</translation>
    </message>
    <message>
        <location filename="kfzcheck.py" line="115"/>
        <source>csv file not found or has not enough rights.</source>
        <translation>csv Datei nicht gefunden oder besitzt nicht genügend Rechte.</translation>
    </message>
    <message>
        <location filename="kfzcheck.py" line="164"/>
        <source>No matches found</source>
        <translation>Keine Übereinstimmungen gefunden</translation>
    </message>
    <message>
        <location filename="kfzcheck_qt.py" line="192"/>
        <source>KFZcheck searches for kfz license plates shortcuts and citys / regions.
 
Uppercase searches for all license plates starting with your search. Lowercase matches exactly for the license plates and searches after the city / region, if no license plate exists.

It&apos;s possible to use other data sources (numbers, city codes, etc.) Visit the project website at http://kfzcheck.yourse.de.

Feedback is welcome at pbeck@yourse.de</source>
        <translation type="obsolete">KFZcheck sucht nach KFZ-Kennzeichen und Städten / Regionen.

Großschreibung sucht nach Kennzeichen die mit der Suche beginnen. Kleinschreibung prüft direkt auf das Kennzeichen und sucht nach der Stadt / Region, wenn kein Kennzeichen gefunden wurde.

Es ist möglich andere Datenquellen (Telefonnummern, Postleitzahlen, etc.) zu nutzen. Besuche die Projekt-Website.

Feedback ist willkommen an pbeck@yourse.de</translation>
    </message>
    <message>
        <location filename="kfzcheck.py" line="76"/>
        <source>Select country</source>
        <translation>Land auswählen</translation>
    </message>
    <message>
        <location filename="kfzcheck.py" line="199"/>
        <source>&lt;p&gt;&lt;span style=&quot; font-size:30pt; text-decoration: bold; color:#ff5c00;&quot;&gt;KFZcheck&lt;/span&gt; searches for kfz license plates shortcuts and citys / regions.&lt;/p&gt;
&lt;p&gt;&lt;span style=&quot; text-decoration: bold; color:#ff5c00;&quot;&gt;Uppercase&lt;/span&gt; searches for all license plates starting with your search. &lt;span style=&quot; text-decoration: bold; color:#ff5c00;&quot;&gt;Lowercase&lt;/span&gt; matches exactly for the license plates and searches after the city / region, if no license plate exists.&lt;/p&gt;

&lt;p&gt;It&apos;s possible to use other data sources (numbers, city codes, etc.) Visit the project website at &lt;a href=&quot;http://kfzcheck.yourse.de&quot;&gt;&lt;span style=&quot; text-decoration: underline; color:#ff5c00;&quot;&gt;http://kfzcheck.yourse.de&lt;/span&gt;&lt;/a&gt;.&lt;/p&gt;

&lt;p&gt;Other data sources has the same search mechanism - look at the order.&lt;/p&gt;

&lt;p&gt;Feedback is welcome at &lt;a href=&quot;mailto:pbeck@yourse.de&quot;&gt;&lt;span style=&quot; text-decoration: bold; color:#ff5c00;&quot;&gt;pbeck@yourse.de&lt;/span&gt;&lt;/p&gt;</source>
        <translation>&lt;p&gt;&lt;span style=&quot; font-size:30pt; text-decoration: bold; color:#ff5c00;&quot;&gt;KFZcheck&lt;/span&gt; sucht nach KFZ-Kennzeichen und Städten /Regionen.&lt;/p&gt;
&lt;p&gt;&lt;span style=&quot; text-decoration: bold; color:#ff5c00;&quot;&gt;Großschreibung&lt;/span&gt; sucht nach Kennzeichen die mit der Suche beginnen. &lt;span style=&quot; text-decoration: bold; color:#ff5c00;&quot;&gt;Kleinschreibung&lt;/span&gt; prüft direkt auf das Kennzeichen und sucht nach der Stadt / Region, wenn kein Kennzeichen gefunden wurde.&lt;/p&gt;

&lt;p&gt;Es ist möglich andere Datenquellen (Telefonnummern, Postleitzahlen, etc.) zu nutzen. Besuche die Projekt-Website auf &lt;a href=&quot;http://kfzcheck.yourse.de&quot;&gt;&lt;span style=&quot; text-decoration: underline; color:#ff5c00;&quot;&gt;http://kfzcheck.yourse.de&lt;/span&gt;&lt;/a&gt;.&lt;/p&gt;

&lt;p&gt;Andere Datenquellen haben die gleiche Suchfunktion - Beachte die Reihenfolge.&lt;/p&gt;

&lt;p&gt;Feedback ist willkommen bei &lt;a href=&quot;mailto:pbeck@yourse.de&quot;&gt;&lt;span style=&quot; text-decoration: bold; color:#ff5c00;&quot;&gt;pbeck@yourse.de&lt;/span&gt;&lt;/p&gt;</translation>
    </message>
</context>
</TS>

==> kfzcheck_2.2-1.tar.gz: kfzcheck-2.2/src/opt/kfzcheck/locale/de_DE.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="de_DE">
<context>
    <name>KFZcheck</name>
    <message>
        <location filename="gui.ui" line="120"/>
        <source>Middle</source>
        <translation>Mitte</translation>
    </message>
    <message>
        <location filename="gui.ui" line="131"/>
        <source>Top</source>
        <translation>Oben</translation>
    </message>
    <message>
        <location filename="gui.ui" line="142"/>
        <source>Bottom</source>
        <translation>Unten</translation>
    </message>
    <message>
        <location filename="gui.ui" line="147"/>
        <source>Country</source>
        <translation type="obsolete">Land</translation>
    </message>
    <message>
        <location filename="kfzcheck.py" line="207"/>
        <source>About</source>
        <translation>Über</translation>
    </message>
    <message>
        <location filename="kfzcheck.py" line="114"/>
        <source>csv file not found or has not enough rights.</source>
        <translation>csv Datei nicht gefunden oder besitzt nicht genügend Rechte.</translation>
    </message>
    <message>
        <location filename="kfzcheck.py" line="163"/>
        <source>No matches found</source>
        <translation>Keine Übereinstimmungen gefunden</translation>
    </message>
    <message>
        <location filename="kfzcheck_qt.py" line="192"/>
        <source>KFZcheck searches for kfz license plates shortcuts and citys / regions.
 
Uppercase searches for all license plates starting with your search. Lowercase matches exactly for the license plates and searches after the city / region, if no license plate exists.

It&apos;s possible to use other data sources (numbers, city codes, etc.) Visit the project website at http://kfzcheck.yourse.de.

Feedback is welcome at pbeck@yourse.de</source>
        <translation type="obsolete">KFZcheck sucht nach KFZ-Kennzeichen und Städten / Regionen.

Großschreibung sucht nach Kennzeichen die mit der Suche beginnen. Kleinschreibung prüft direkt auf das Kennzeichen und sucht nach der Stadt / Region, wenn kein Kennzeichen gefunden wurde.

Es ist möglich andere Datenquellen (Telefonnummern, Postleitzahlen, etc.) zu nutzen. Besuche die Projekt-Website.

Feedback ist willkommen an pbeck@yourse.de</translation>
    </message>
    <message>
        <location filename="kfzcheck.py" line="74"/>
        <source>Select country</source>
        <translation type="obsolete">Land auswählen</translation>
    </message>
    <message>
        <location filename="kfzcheck.py" line="199"/>
        <source>&lt;p&gt;&lt;span style=&quot; font-size:30pt; text-decoration: bold; color:#ff5c00;&quot;&gt;KFZcheck&lt;/span&gt; searches for kfz license plates shortcuts and citys / regions.&lt;/p&gt;
&lt;p&gt;&lt;span style=&quot; text-decoration: bold; color:#ff5c00;&quot;&gt;Uppercase&lt;/span&gt; searches for all license plates starting with your search. &lt;span style=&quot; text-decoration: bold; color:#ff5c00;&quot;&gt;Lowercase&lt;/span&gt; matches exactly for the license plates and searches after the city / region, if no license plate exists.&lt;/p&gt;

&lt;p&gt;It&apos;s possible to use other data sources (numbers, city codes, etc.) Visit the project website at &lt;a href=&quot;http://kfzcheck.yourse.de&quot;&gt;&lt;span style=&quot; text-decoration: underline; color:#ff5c00;&quot;&gt;http://kfzcheck.yourse.de&lt;/span&gt;&lt;/a&gt;.&lt;/p&gt;

&lt;p&gt;Other data sources has the same search mechanism - look at the order.&lt;/p&gt;

&lt;p&gt;Feedback is welcome at &lt;a href=&quot;mailto:pbeck@yourse.de&quot;&gt;&lt;span style=&quot; text-decoration: bold; color:#ff5c00;&quot;&gt;pbeck@yourse.de&lt;/span&gt;&lt;/p&gt;</source>
        <translation type="obsolete">&lt;p&gt;&lt;span style=&quot; font-size:30pt; text-decoration: bold; color:#ff5c00;&quot;&gt;KFZcheck&lt;/span&gt; sucht nach KFZ-Kennzeichen und Städten /Regionen.&lt;/p&gt;
&lt;p&gt;&lt;span style=&quot; text-decoration: bold; color:#ff5c00;&quot;&gt;Großschreibung&lt;/span&gt; sucht nach Kennzeichen die mit der Suche beginnen. &lt;span style=&quot; text-decoration: bold; color:#ff5c00;&quot;&gt;Kleinschreibung&lt;/span&gt; prüft direkt auf das Kennzeichen und sucht nach der Stadt / Region, wenn kein Kennzeichen gefunden wurde.&lt;/p&gt;

&lt;p&gt;Es ist möglich andere Datenquellen (Telefonnummern, Postleitzahlen, etc.) zu nutzen. Besuche die Projekt-Website auf &lt;a href=&quot;http://kfzcheck.yourse.de&quot;&gt;&lt;span style=&quot; text-decoration: underline; color:#ff5c00;&quot;&gt;http://kfzcheck.yourse.de&lt;/span&gt;&lt;/a&gt;.&lt;/p&gt;

&lt;p&gt;Andere Datenquellen haben die gleiche Suchfunktion - Beachte die Reihenfolge.&lt;/p&gt;

&lt;p&gt;Feedback ist willkommen bei &lt;a href=&quot;mailto:pbeck@yourse.de&quot;&gt;&lt;span style=&quot; text-decoration: bold; color:#ff5c00;&quot;&gt;pbeck@yourse.de&lt;/span&gt;&lt;/p&gt;</translation>
    </message>
    <message>
        <location filename="kfzcheck.py" line="198"/>
        <source>&lt;p&gt;&lt;span style=&quot; font-size:30pt; text-decoration: bold; color:#ff5c00;&quot;&gt;KFZcheck&lt;/span&gt; searches for kfz license plates shortcuts and cities / regions.&lt;/p&gt;
&lt;p&gt;&lt;span style=&quot; text-decoration: bold; color:#ff5c00;&quot;&gt;Uppercase&lt;/span&gt; searches for all license plates starting with your search. &lt;span style=&quot; text-decoration: bold; color:#ff5c00;&quot;&gt;Lowercase&lt;/span&gt; matches exactly for the license plates and searches after the city / region, if no license plate exists.&lt;/p&gt;

&lt;p&gt;It&apos;s possible to use other data sources (numbers, city codes, etc.) Visit the project website at &lt;a href=&quot;http://kfzcheck.yourse.de&quot;&gt;&lt;span style=&quot; text-decoration: underline; color:#ff5c00;&quot;&gt;http://kfzcheck.yourse.de&lt;/span&gt;&lt;/a&gt;.&lt;/p&gt;

&lt;p&gt;Other data sources has the same search mechanism - look at the order.&lt;/p&gt;

&lt;p&gt;Feedback is welcome at &lt;a href=&quot;mailto:pbeck@yourse.de&quot;&gt;&lt;span style=&quot; text-decoration: bold; color:#ff5c00;&quot;&gt;pbeck@yourse.de&lt;/span&gt;&lt;/p&gt;</source>
        <translation>&lt;p&gt;&lt;span style=&quot; font-size:30pt; text-decoration: bold; color:#ff5c00;&quot;&gt;KFZcheck&lt;/span&gt; sucht nach KFZ-Kennzeichen und Städten /Regionen.&lt;/p&gt;
&lt;p&gt;&lt;span style=&quot; text-decoration: bold; color:#ff5c00;&quot;&gt;Großschreibung&lt;/span&gt; sucht nach Kennzeichen die mit der Suche beginnen. &lt;span style=&quot; text-decoration: bold; color:#ff5c00;&quot;&gt;Kleinschreibung&lt;/span&gt; prüft direkt auf das Kennzeichen und sucht nach der Stadt / Region, wenn kein Kennzeichen gefunden wurde.&lt;/p&gt;

&lt;p&gt;Es ist möglich andere Datenquellen (Telefonnummern, Postleitzahlen, etc.) zu nutzen. Besuche die Projekt-Website auf &lt;a href=&quot;http://kfzcheck.yourse.de&quot;&gt;&lt;span style=&quot; text-decoration: underline; color:#ff5c00;&quot;&gt;http://kfzcheck.yourse.de&lt;/span&gt;&lt;/a&gt;.&lt;/p&gt;

&lt;p&gt;Andere Datenquellen haben die gleiche Suchfunktion - Beachte die Reihenfolge.&lt;/p&gt;

&lt;p&gt;Feedback ist willkommen bei &lt;a href=&quot;mailto:pbeck@yourse.de&quot;&gt;&lt;span style=&quot; text-decoration: bold; color:#ff5c00;&quot;&gt;pbeck@yourse.de&lt;/span&gt;&lt;/p&gt;</translation>
    </message>
    <message>
        <location filename="gui.ui" line="147"/>
        <source>File</source>
        <translation>Datei</translation>
    </message>
    <message>
        <location filename="kfzcheck.py" line="74"/>
        <source>Select file</source>
        <translation>Datei auswählen</translation>
    </message>
</context>
</TS>
